==> vtk6-6.3.0-2-armv6h.pkg.tar.xz: vtk/vtkPExodusIIReader.java <==
// java wrapper for vtkPExodusIIReader object
//

package vtk;
import vtk.*;

public class vtkPExodusIIReader extends vtkExodusIIReader
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetController_2(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_2(id0); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetFilePattern_4(String id0);
  public void SetFilePattern(String id0)
    { SetFilePattern_4(id0); }

  private native String GetFilePattern_5();
  public String GetFilePattern()
    { return GetFilePattern_5(); }

  private native void SetFilePrefix_6(String id0);
  public void SetFilePrefix(String id0)
    { SetFilePrefix_6(id0); }

  private native String GetFilePrefix_7();
  public String GetFilePrefix()
    { return GetFilePrefix_7(); }

  private native void SetFileRange_8(int id0,int id1);
  public void SetFileRange(int id0,int id1)
    { SetFileRange_8(id0,id1); }

  private native int[]  GetFileRange_9();
  public int[]  GetFileRange()
    { return GetFileRange_9(); }

  private native void SetFileName_10(String id0);
  public void SetFileName(String id0)
    { SetFileName_10(id0); }

  private native int GetNumberOfFileNames_11();
  public int GetNumberOfFileNames()
    { return GetNumberOfFileNames_11(); }

  private native int GetNumberOfFiles_12();
  public int GetNumberOfFiles()
    { return GetNumberOfFiles_12(); }

  private native int GetTotalNumberOfElements_13();
  public int GetTotalNumberOfElements()
    { return GetTotalNumberOfElements_13(); }

  private native int GetTotalNumberOfNodes_14();
  public int GetTotalNumberOfNodes()
    { return GetTotalNumberOfNodes_14(); }

  private native void Broadcast_15(vtkMultiProcessController id0);
  public void Broadcast(vtkMultiProcessController id0)
    { Broadcast_15(id0); }

  private native double GetVariableCacheSize_16();
  public double GetVariableCacheSize()
    { return GetVariableCacheSize_16(); }

  private native void SetVariableCacheSize_17(double id0);
  public void SetVariableCacheSize(double id0)
    { SetVariableCacheSize_17(id0); }

  public vtkPExodusIIReader() { super(); }

  public vtkPExodusIIReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv6h.pkg.tar.xz: vtk/vtkPExodusIIReader.java <==
// java wrapper for vtkPExodusIIReader object
//

package vtk;
import vtk.*;

public class vtkPExodusIIReader extends vtkExodusIIReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetController_2(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_2(id0); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFilePattern_4(String id0);
  public void SetFilePattern(String id0)
    { SetFilePattern_4(id0); }

  private native String GetFilePattern_5();
  public String GetFilePattern()
    { return GetFilePattern_5(); }

  private native void SetFilePrefix_6(String id0);
  public void SetFilePrefix(String id0)
    { SetFilePrefix_6(id0); }

  private native String GetFilePrefix_7();
  public String GetFilePrefix()
    { return GetFilePrefix_7(); }

  private native void SetFileRange_8(int id0,int id1);
  public void SetFileRange(int id0,int id1)
    { SetFileRange_8(id0,id1); }

  private native int[]  GetFileRange_9();
  public int[]  GetFileRange()
    { return GetFileRange_9(); }

  private native void SetFileName_10(String id0);
  public void SetFileName(String id0)
    { SetFileName_10(id0); }

  private native int GetNumberOfFileNames_11();
  public int GetNumberOfFileNames()
    { return GetNumberOfFileNames_11(); }

  private native int GetNumberOfFiles_12();
  public int GetNumberOfFiles()
    { return GetNumberOfFiles_12(); }

  private native int GetTotalNumberOfElements_13();
  public int GetTotalNumberOfElements()
    { return GetTotalNumberOfElements_13(); }

  private native int GetTotalNumberOfNodes_14();
  public int GetTotalNumberOfNodes()
    { return GetTotalNumberOfNodes_14(); }

  private native void Broadcast_15(vtkMultiProcessController id0);
  public void Broadcast(vtkMultiProcessController id0)
    { Broadcast_15(id0); }

  private native double GetVariableCacheSize_16();
  public double GetVariableCacheSize()
    { return GetVariableCacheSize_16(); }

  private native void SetVariableCacheSize_17(double id0);
  public void SetVariableCacheSize(double id0)
    { SetVariableCacheSize_17(id0); }

  public vtkPExodusIIReader() { super(); }

  public vtkPExodusIIReader(long id) { super(id); }
  public native long   VTKInit();

}
